==> 0.2.6.tar.gz: android/src/main/java/com/example/attestr_flowx_plugin/AttestrFlowxPlugin.java <==
package com.example.attestr_flowx_plugin;

import android.app.Activity;
import android.text.TextUtils;
import android.util.Log;

import androidx.annotation.NonNull;

import com.attestr.flowx.AttestrFlowx;
import com.attestr.flowx.listener.AttestrFlowXListener;

import java.util.HashMap;
import java.util.Map;

import io.flutter.embedding.android.FlutterActivity;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/** AttestrFlowxPlugin */
public class AttestrFlowxPlugin
        implements FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity

  private static final String CHANNEL_NAME = "attestr_flowx_plugin";
  private MethodChannel channel;
//  private AttestrFlowxDelegate attestrFlowxDelegate;

  private static final int FLOW_COMPLETE = 0;
  private static final int FLOW_SKIP = 1;
  private static final int FLOW_ERROR = 2;
  private static final String TAG = "AttestrFlowxDelegate";
  private final AttestrFlowx attestrFlowx = new AttestrFlowx();
  private Result pendingResult;
  private FlutterActivity mActivity;
  private AttestrFlowxDelegate attestrFlowxDelegate;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), CHANNEL_NAME);
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
//    channel.setMethodCallHandler((call, result) -> {
//      if (call.method.equals("getPlatformVersion")) {
//        result.success("Android " + android.os.Build.VERSION.RELEASE);
//      } else if (call.method.equals("initiateSession")) {
//        AttestrFlowxDelegate attestrFlowxDelegate = new AttestrFlowxDelegate(binding.getActivity());
//        attestrFlowxDelegate.initiateSession(call, result);
//      } else {
//        result.notImplemented();
//      }
//    });
    this.mActivity = (FlutterActivity) binding.getActivity();
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else if (call.method.equals("initiateSession")) {
      attestrFlowxDelegate = new AttestrFlowxDelegate();
      attestrFlowxDelegate.initiateSession(call, result);
    } else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {
    onDetachedFromActivity();
  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
    onAttachedToActivity(binding);
  }

  @Override
  public void onDetachedFromActivity() {

  }

}

==> 0.2.7.tar.gz: android/src/main/java/com/example/attestr_flowx_plugin/AttestrFlowxPlugin.java <==
package com.example.attestr_flowx_plugin;

import android.app.Activity;
import android.content.Context;

import androidx.annotation.NonNull;

import com.attestr.flowx.AttestrFlowx;

import io.flutter.embedding.android.FlutterActivity;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;

/** AttestrFlowxPlugin */
public class AttestrFlowxPlugin
        implements FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity

  private static final String CHANNEL_NAME = "attestr_flowx_plugin";
  private MethodChannel channel;

  private static final String TAG = "AttestrFlowxDelegate";
  private Activity mActivity;
  private AttestrFlowxDelegate attestrFlowxDelegate;
  private Context mContext;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), CHANNEL_NAME);
    channel.setMethodCallHandler(this);
    this.mContext = flutterPluginBinding.getApplicationContext();
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    this.mActivity = binding.getActivity();
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else if (call.method.equals("initiateSession")) {
      attestrFlowxDelegate = new AttestrFlowxDelegate(mActivity);
      attestrFlowxDelegate.initiateSession(call, result);
    } else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {
    onDetachedFromActivity();
  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
    onAttachedToActivity(binding);
  }

  @Override
  public void onDetachedFromActivity() {

  }

}
